import React, { useState, useEffect, memo } from 'react';
import { LoadingOutlined, PlusOutlined, CloseOutlined } from '@ant-design/icons';
import { Image, Upload } from 'antd';
import type { UploadProps } from 'antd';
import styles from './index.less';

interface IItemImage {
  id: number;
  url: string;
}

interface IBanner {
  type: number;
  dataSource: IItemImage[];
  onChange: (info: any, type: number) => void;
  onDelFile: (id: number) => void;
}

const Banner: React.FC<IBanner> = ({ type, dataSource, onChange, onDelFile }) => {
  const [loading, setLoading] = useState(false);
  const [dataList, setDataList] = useState<IItemImage[]>(dataSource);

  const handleChange: UploadProps['onChange'] = async (info) => {
    if (info.file.status === 'uploading') {
      setLoading(true);
      return;
    }
    if (info.file.status === 'done') {
      onChange?.(info, type);
    }
    setLoading(false);
  };

  useEffect(() => {
    setDataList(dataSource);
  }, [dataSource]);

  const uploadButton = (
    <button style={{ border: 0, background: 'none' }} type="button">
      {loading ? <LoadingOutlined /> : <PlusOutlined />}
      <div style={{ marginTop: 8 }}>上传图片</div>
    </button>
  );

  return (
    <>
      <Image.PreviewGroup
        preview={{
          onChange: (current, prev) =>
            console.log(`current index: ${current}, prev index: ${prev}`),
        }}
      >
        <div className={styles.bannerWrapper}>
          {dataList.map((item) => {
            return (
              <div key={item.id} className={styles.bannerItem}>
                <Image width="100%" height={250} src={item.url} />
                <div className={styles.operation} onClick={() => onDelFile(item.id)}>
                  <CloseOutlined />
                </div>
              </div>
            );
          })}
        </div>
      </Image.PreviewGroup>
      <div className={styles.uploadWrapper}>
        <Upload
          accept=".png,.jpg,.jpeg,.gif,.webp,.svg"
          name="file"
          listType="picture-circle"
          className={`avatar-uploader uploadBtn`}
          showUploadList={false}
          onChange={handleChange}
        >
          {uploadButton}
        </Upload>
      </div>
    </>
  );
};

export default memo(Banner);
